==> haskell-yesod-form-1.7.9-114-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-LDRNXkVzIQn6wBOPtW0LWZ
key:                  yesod-form-1.7.9-LDRNXkVzIQn6wBOPtW0LWZ
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  e22774085e76ce983f2869556f9797e2
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-LDRNXkVzIQn6wBOPtW0LWZ
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW base-4.17.2.1
    blaze-builder-0.4.4-1ntb6RP4OewIlLWEkSeIAR
    blaze-html-0.9.2.0-BsVDj7UmD9SGJonPOQFUuj
    blaze-markup-0.8.3.0-Ey7XmXUOs4eDBTvJFYpeuT
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.2-7bG7braRZax6ZJaJ3dSesR
    email-validate-2.3.2.21-3IGxfCgjyVoHQattXscdOy
    network-uri-2.6.4.2-6dAHdOyJLq76CXdDmIsqEl
    persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP
    shakespeare-2.1.4-XhBO6YdeYk8lLmfKbanJy text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-LnpkwzoHUW9G2cGUC0nKUm
    xss-sanitize-0.3.7.2-2rM1fBjR8Df9EcYYfuGxmc
    yesod-core-1.6.27.1-KFoprkJXhJa2ewlge46soy
    yesod-persistent-1.6.0.8-GbxYOR2HCDw5mSWSv7LbxG

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.7.9-143-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-form
version:              1.7.9
visibility:           public
id:                   yesod-form-1.7.9-DRYl9E9h5BgDPl9gkPOGpC
key:                  yesod-form-1.7.9-DRYl9E9h5BgDPl9gkPOGpC
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currently it provides only Summernote support).

category:             Web, Yesod
abi:                  0028c6f3ae0a633b9919a49dbf3d06d5
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Romanian Yesod.Form.I18n.Russian
    Yesod.Form.I18n.Spanish Yesod.Form.I18n.Swedish Yesod.Form.Input
    Yesod.Form.Jquery Yesod.Form.MassInput Yesod.Form.Nic
    Yesod.Form.Option Yesod.Form.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-form-1.7.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-form
hs-libraries:         HSyesod-form-1.7.9-DRYl9E9h5BgDPl9gkPOGpC
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y base-4.17.2.1
    blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz
    blaze-html-0.9.2.0-3cSCYM9QSR99BQnVHXrYzE
    blaze-markup-0.8.3.0-gQO1lU2QPQ9hXIev9mjlD
    byteable-0.1.1-BiXMgwkGoIQH63GBEhxKBY bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-1SaGr9SWFYZ17MG1fTAOKi
    email-validate-2.3.2.21-6kw9MkAdKYr6Y3hz9Gn0US
    network-uri-2.6.4.2-DVBcu05aYxxCjTvpzOd17v
    persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl
    shakespeare-2.1.7-8Tdsqxebqs756ICmE3o1IV text-2.0.2 time-1.12.2
    transformers-0.5.6.2 wai-3.2.4-GKgviHtnWhO3KoBTtmAmpl
    xss-sanitize-0.3.7.2-AeSM24YsTfE3PT9JYVBBm1
    yesod-core-1.6.27.1-EwsliX2Eq0V3h6VQF9toZp
    yesod-persistent-1.6.0.8-5LBIN6k6CwtDeQL9oX4i2b

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
